@@ -6,6 +6,7 @@ from __future__ import unicode_literals
 
 from base64 import b64encode
 import typing
+import errno
 from io import BufferedReader, BytesIO, StringIO
 import gc
 import logging
@@ -14,7 +15,7 @@ import re
 from ssl import get_default_verify_paths
 import time
 import threading
-from urllib.parse import quote
+from urllib.parse import quote, parse_qs, urlparse
 import warnings
 
 # pylint: disable=no-name-in-module
@@ -35,7 +36,7 @@ from .extensions.bs_requests import Request as BsRequest
 from .extensions.search import Search
 from .extensions.users import Group, Person
 from .utils.auth import HttpSignatureAuth
-from .utils.conf import get_credentials
+from .utils.conf import BOOLEAN_PARAMS, get_credentials
 from .utils.errors import OscError
 
 try:
@@ -321,7 +322,11 @@ class Osc:
                          "\n".join(f"{k}: {v}" for k, v in req.data.items())
                          if isinstance(req.data, dict) else req.data)
             logger.debug("Sent parameters:\n%s\n---",
-                         "\n".join(f"{k}: {v}" for k, v in req.params.items()))
+                         "\n".join(f"{k}: {v}" for k, v in (
+                             req.params
+                             if isinstance(req.params, dict)
+                             else parse_qs(req.params, keep_blank_values=True)
+                         ).items()))
             try:
                 response = session.send(prepped_req, **settings)
             except _ConnectionError as error:
@@ -349,7 +354,15 @@ class Osc:
         Translate request parameters to API conform format
 
         .. note:: The build service does not handle URL-encoded Unicode well.
-                  Therefore parameters are encoded as ``bytes``.
+                  Therefore, parameters are encoded as ``bytes``.
+
+        .. warning:: The build service does not declare its parameters properly and developers do
+                     `not intend to fix`_ this server-side. If you want to use _boolean_ parameters,
+                     make sure to use ``True`` and ``False``. If you use ``0`` or ``1`` instead, you
+                     might receive unexpected results.
+
+                     .. _not intend to fix: https://github.com/openSUSE/open-build-service/issues
+                                            /9715
 
         :param params: Request parameter
         :type params: dict or str or io.BufferedReader
@@ -373,13 +386,61 @@ class Osc:
         if not isinstance(params, dict):
             return {}
 
-        for key in params:
-            if isinstance(params[key], bool):
-                params[key] = '1' if params[key] else '0'
+        # The OBS API has a weird expectation regarding boolean parameters and the maintainers have
+        # made it clear, that they are not going to clean up the API :(
+        # See: https://github.com/openSUSE/open-build-service/issues/9715
+        unexpected_bools = {key for key, value in params.items()
+                            if isinstance(value, bool) and key not in BOOLEAN_PARAMS}
+        if unexpected_bools:
+            warnings.warn(f"Received boolean query params, which are not expected to be: "
+                          f"{', '.join(unexpected_bools)}")
 
-        return {key.encode(): str(value).encode()
+        return "&".join(
+            quote(str(key))
+            if key in BOOLEAN_PARAMS or value is True
+            else f"{quote(str(key))}={quote(str(value))}"
+            for key, value in (
+                (key, value)
                 for key, value in params.items()
-                if value is not None}
+                if not ((key in BOOLEAN_PARAMS or isinstance(value, bool) or value is None)
+                        and value in [False, "0", 0, None])
+            )
+        ).encode()
+
+    def download(self, url, destdir, destfile=None, overwrite=False, **params):
+        """
+        Shortcut for a streaming GET request
+
+        :param str url: Download URL
+        :param pathlib.Path destdir: Destination directory
+        :param str destfile: Target file name. If not specified, it will be taken from the URL
+        :param bool overwrite: switch to overwrite existing downloaded file
+        :param params: Additional query params
+        :return: absolute path to file or ``None``
+
+        .. versionadded:: 0.7.0
+        """
+        destdir = destdir if isinstance(destdir, Path) else Path(destdir)
+        if not destfile:
+            parsed = urlparse(url)
+            destfile = Path(parsed.path).name
+
+        if destdir.is_file():
+            raise OSError(errno.EEXIST, "Target directory is a file", destdir)
+
+        target = destdir.joinpath(destfile)
+        if not overwrite and target.exists():
+            raise OSError(errno.EEXIST, "File already exists", target)
+        if not destdir.exists():
+            destdir.mkdir(parents=True, exist_ok=True)
+
+        response = self.request(url=url, method="GET", stream=True, params=params)
+
+        with target.open("wb") as handle:
+            for chunk in response.iter_content(1024):
+                handle.write(chunk)
+
+        return target
 
     def get_objectified_xml(self, response):
         """
