@@ -24,8 +24,8 @@ class TestProject(OscTest):
             </directory>
             """
             parsed = urlparse(request.url)
-            params.update(parse_qs(parsed.query))
-            if params.get("deleted", ["0"]) == ["1"]:
+            params.update(parse_qs(parsed.query, keep_blank_values=True))
+            if "deleted" in params:
                 status = 403
                 body = """<status code="no_permission_for_deleted">
                   <summary>only admins can see deleted projects</summary>
@@ -165,9 +165,9 @@ class TestProject(OscTest):
                 </directory>
             """
             parsed = urlparse(request.url)
-            params.update(parse_qs(parsed.query))
+            params.update(parse_qs(parsed.query, keep_blank_values=True))
 
-            if params.get("meta", ['0']) == ['1']:
+            if "meta" in params:
                 status = 200
                 body = """
                     <directory name="_project" rev="41" vrev="" 
@@ -267,6 +267,7 @@ class TestProject(OscTest):
     @responses.activate
     def test_set_attribute(self):
         def callback(headers, params, request):
+            self.assertEqual(request.body, expected)
             status, body = 200, "<status code='ok'></status>"
             return status, headers, body
 
@@ -278,13 +279,27 @@ class TestProject(OscTest):
             callback=CallbackFactory(callback)
         )
 
-        self.assertTrue(
-            self.osc.projects.set_attribute(
-                project="test:project",
-                attribute="namespace:attr",
-                value="value"
+        with self.subTest("Single value"):
+            expected = b'<attributes><attribute namespace="namespace" name="attr">' \
+                       b'<value>value</value></attribute></attributes>'
+            self.assertTrue(
+                self.osc.projects.set_attribute(
+                    project="test:project",
+                    attribute="namespace:attr",
+                    value="value"
+                )
+            )
+
+        with self.subTest("Two values"):
+            expected = b'<attributes><attribute namespace="namespace" name="attr">' \
+                       b'<value>value1</value><value>value2</value></attribute></attributes>'
+            self.assertTrue(
+                self.osc.projects.set_attribute(
+                    project="test:project",
+                    attribute="namespace:attr",
+                    value=["value1", "value2"]
+                )
             )
-        )
 
     @responses.activate
     def test_delete_attribute(self):
